package com.mosty.yjzl.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.mosty.base.model.dto.yjzl.*;
import com.mosty.base.model.query.yjzl.TbYjqkQuery;
import io.swagger.annotations.ApiOperation;

import java.util.List;
import java.util.Map;

public interface YjzlStatisticsService {

    @ApiOperation("车辆预警列表TOP")
    List<Map<String, Object>> clyjlb(TbYjxxStatisticsDto vo);

    @ApiOperation("根据车牌号查询")
    List<Map<String, Object>> queryBycCphm(TbYjxxPageStatisticsDto vo);

    @ApiOperation("根据车牌号查询预警列表-日")
    List<Map<String, Object>> queryBycCphmlb(TbYjxxPageStatisticsDto vo);

    @ApiOperation("根据车牌号查询预警列表-月")
    List<Map<String, Object>> yqueryBycCphmlb(TbYjxxYStatisticsDto vo);

    @ApiOperation("根据车牌号查询预警列表-月")
    List<Map<String, Object>> zqueryBycCphmlb(TbYjxxPageStatisticsDto dto);

    @ApiOperation("日预警车辆TOP20")
    List<Map<String, Object>> yjcltj(TbYjxxStatisticsDto dto);

    @ApiOperation("预警标签统计")
    List<Map<String, Object>> yjbqtj(TbYjxxStatisticsDto dto);

    @ApiOperation("预警级别统计")
    List<Map<String, Object>> yjjbtj(TbYjxxStatisticsDto dto);

    @ApiOperation("月预警车辆TOP20")
    List<Map<String, Object>> yyjcltj(TbYjxxYStatisticsDto dto);

    @ApiOperation("周预警车辆TOP20")
    List<Map<String, Object>> zyjcltj(TbYjxxStatisticsDto dto);

    @ApiOperation("根据身份证查询--人员")
    List<Map<String, Object>> queryBySfzh(TbYjxxRyStatisticsDto dto);

    @ApiOperation("根据身份证查询列表-日")
    List<Map<String, Object>> queryBySfzhlb(TbYjxxRyPageStatisticsDto dto);

    @ApiOperation("根据身份证查询列表-日(三车前科人员)")
    List<Map<String, Object>> queryBySfzhlbsc(TbYjxxRyPageStatisticsDto dto);

    @ApiOperation("根据身份证查询列表-月")
    List<Map<String, Object>> yqueryBySfzhlb(TbYjxxRyNyStatisticsDto dto);

    @ApiOperation("根据身份证查询列表-月(三车前科人员)")
    List<Map<String, Object>> yqueryBySfzhlbsc(TbYjxxRyNyStatisticsDto dto);

    @ApiOperation("根据身份证查询列表-周")
    List<Map<String, Object>> zqueryBySfzhlb(TbYjxxRyPageStatisticsDto dto);

    @ApiOperation("根据身份证查询列表-周(三车前科人员)")
    List<Map<String, Object>> zqueryBySfzhlbsc(TbYjxxRyPageStatisticsDto dto);

    @ApiOperation("人员预警列表TOP")
    List<Map<String, Object>> ryyjlb(TbYjxxStatisticsDto dto);

    @ApiOperation("预警级别统计")
    List<Map<String, Object>> yjjbtjRy(TbYjxxStatisticsDto dto);

    @ApiOperation("预警人员级别统计")
    List<Map<String, Object>> jbtj(TbYjxxStatisticsDto dto);

    @ApiOperation("预警人员TOP20")
    List<Map<String, Object>> yjrytj(TbYjxxStatisticsDto dto);

    @ApiOperation("预警人员TOP20(三车前科人员)")
    List<Map<String, Object>> yjrytjsc(TbYjxxStatisticsDto dto);

    @ApiOperation("月预警人员TOP20")
    List<Map<String, Object>> yyjrytj(TbYjxxYyjStatisticsDto dto);

    @ApiOperation("月预警人员TOP20(三车前科人员)")
    List<Map<String, Object>> yyjrytjsc(TbYjxxYyjStatisticsDto dto);

    @ApiOperation("周预警人员TOP20")
    List<Map<String, Object>> zyjrytj(TbYjxxStatisticsDto dto);

    @ApiOperation("周预警人员TOP20(三车前科人员)")
    List<Map<String, Object>> zyjrytjsc(TbYjxxStatisticsDto dto);

    @ApiOperation("周边预警列表(不分页)")
    List<Map<String, Object>> zbyjbfylb(TbYjxxRyPageStatisticsDto dto);

    @ApiOperation("周边预警统计")
    List<Map<String, Object>> zbyjtj(TbYjxxStatisticsDto dto);

    @ApiOperation("感知源预警排名")
    List<Map<String, Object>> gzyyjpm(TbYjxxStatisticsDto dto);

    @ApiOperation("派出所预警排名")
    List<Map<String, Object>> pcsyjpm(TbYjxxStatisticsDto dto);

    @ApiOperation("人员预警排名")
    List<Map<String, Object>> ryyjpm(TbYjxxStatisticsDto dto);

    @ApiOperation("右侧预警统计")
    List<Map<String, Object>> ycyjtj(TbYjxxStatisticsQueryDto dto);

    @ApiOperation("预警中心--预警统计")
    List<Map<String, Object>> yjtj();

    @ApiOperation("泸州态势统计-各区县预警情况")
    Map<String, Object> getGqxyjqk(TbYjqkQuery dto);

    @ApiOperation("泸州态势统计-警情与预警指令执行对比分析")
    Map<String, Object> getJqscAndZlTj(TbYjqkQuery dto);
}
